@@ -1,3 +1,4 @@
+from content_editor.models import Type
 from django import forms
 from django.db import models
 from django.db.models import signals
@@ -5,8 +6,32 @@ from django.db.models.fields import BLANK_CHOICE_DASH
 from django.utils.module_loading import import_string
 from django.utils.text import slugify
 from django.utils.translation import gettext_lazy as _
-from feincms3.mixins import ChoicesCharField
-from feincms3.utils import validation_error
+from feincms3.utils import ChoicesCharField, validation_error
+
+
+def import_if_string(obj_or_path):
+    return import_string(obj_or_path) if isinstance(obj_or_path, str) else obj_or_path
+
+
+class ImportDescriptor:
+    def __set_name__(self, owner, name):
+        self._name = name
+
+    def __get__(self, obj, type=None):
+        return import_if_string(obj.get(self._name))
+
+
+class FormType(Type):
+    _REQUIRED = {"key", "label", "regions", "form_class", "validate"}
+
+    def __init__(self, **kwargs):
+        kwargs.setdefault("form_class", forms.Form)
+        kwargs.setdefault("validate", lambda form: [])
+        super().__init__(**kwargs)
+
+    form_class = ImportDescriptor()
+    process = ImportDescriptor()
+    validate = ImportDescriptor()
 
 
 class ConfiguredForm(models.Model):
@@ -25,7 +50,7 @@ class ConfiguredForm(models.Model):
     @property
     def regions(self):
         try:
-            return self.form_class.regions
+            return self.type.regions
         except (AttributeError, KeyError):
             return []
 
@@ -35,10 +60,8 @@ class ConfiguredForm(models.Model):
             field = sender._meta.get_field("form")
             field.choices = [(row["key"], row["label"]) for row in sender.FORMS]
 
-            form_classes = {row["key"]: row["form_class"] for row in sender.FORMS}
-            sender.form_class = property(
-                lambda self: import_string(form_classes[self.form])
-            )
+            types = {type.key: type for type in sender.FORMS}
+            sender.type = property(lambda self: import_if_string(types[self.form]))
 
 
 signals.class_prepared.connect(ConfiguredForm.fill_form_choices)
